import { DynamicFormControlComponent, DynamicFormLayoutService, DynamicFormValidationService, DynamicCheckboxModel, DynamicInputModel, DynamicDatePickerModel, DynamicTextAreaModel, DynamicSwitchModel, DynamicSliderModel, DynamicRadioGroupModel, DynamicSelectModel, DynamicFormGroupComponent, DynamicFormGroupModel, DynamicFormControlContainerComponent, DYNAMIC_FORM_CONTROL_TYPE_DATEPICKER, DYNAMIC_FORM_CONTROL_TYPE_INPUT, DYNAMIC_FORM_CONTROL_TYPE_SELECT, DYNAMIC_FORM_CONTROL_TYPE_TEXTAREA, DynamicFormValueControlModel, DynamicFormComponentService, DynamicFormRelationService, DynamicTemplateDirective, DynamicFormArrayGroupModel, DynamicFormControlModel, DYNAMIC_FORM_CONTROL_TYPE_SWITCH, DYNAMIC_FORM_CONTROL_TYPE_SLIDER, DYNAMIC_FORM_CONTROL_TYPE_RADIO_GROUP, DYNAMIC_FORM_CONTROL_TYPE_GROUP, DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX_GROUP, DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX, DYNAMIC_FORM_CONTROL_TYPE_ARRAY, DynamicFormArrayComponent, DynamicFormArrayModel, DynamicFormComponent, DynamicFormsCoreModule } from '@ng-dynamic-forms/core';
import { __decorate, __metadata, __param } from 'tslib';
import { EventEmitter, Inject, Optional, Input, Output, ViewChild, Component, ViewChildren, forwardRef, QueryList, ChangeDetectorRef, ComponentFactoryResolver, ContentChildren, HostBinding, ViewContainerRef, ChangeDetectionStrategy, NgModule } from '@angular/core';
import { FormGroup, ReactiveFormsModule } from '@angular/forms';
import { MatCheckbox, MatCheckboxModule } from '@angular/material/checkbox';
import { MAT_RIPPLE_GLOBAL_OPTIONS, MAT_LABEL_GLOBAL_OPTIONS, ErrorStateMatcher } from '@angular/material/core';
import { MAT_AUTOCOMPLETE_DEFAULT_OPTIONS, MatAutocomplete, MatAutocompleteModule } from '@angular/material/autocomplete';
import { MAT_CHIPS_DEFAULT_OPTIONS, MatChipList, MatChipsModule } from '@angular/material/chips';
import { MatInput, MatInputModule } from '@angular/material/input';
import { MatDatepicker, MatDatepickerModule } from '@angular/material/datepicker';
import { MatSlideToggle, MatSlideToggleModule } from '@angular/material/slide-toggle';
import { MatSlider, MatSliderModule } from '@angular/material/slider';
import { MatRadioGroup, MatRadioModule } from '@angular/material/radio';
import { MatSelect, MatSelectModule } from '@angular/material/select';
import { CommonModule } from '@angular/common';
import { MatIconModule } from '@angular/material/icon';
import { TextMaskModule } from 'angular2-text-mask';

class DynamicMaterialFormInputControlComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
    }
    get characterCount() {
        return this.matInput ? this.matInput.value.length : null;
    }
    get characterHint() {
        return `${this.characterCount} / ${this.model.maxLength}`;
    }
    get showCharacterHint() {
        return !!(this.model.maxLength && this.characterCount);
    }
}

let DynamicMaterialCheckboxComponent = class DynamicMaterialCheckboxComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService, RIPPLE_OPTIONS) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.RIPPLE_OPTIONS = RIPPLE_OPTIONS;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicMaterialCheckboxComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_RIPPLE_GLOBAL_OPTIONS,] }, { type: Optional }] }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialCheckboxComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicMaterialCheckboxComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialCheckboxComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicCheckboxModel)
], DynamicMaterialCheckboxComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialCheckboxComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialCheckboxComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialCheckboxComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialCheckboxComponent.prototype, "focus", void 0);
__decorate([
    ViewChild("matCheckbox", { static: true }),
    __metadata("design:type", MatCheckbox)
], DynamicMaterialCheckboxComponent.prototype, "matCheckbox", void 0);
DynamicMaterialCheckboxComponent = __decorate([
    Component({
        selector: "dynamic-material-checkbox",
        template: "<ng-container [formGroup]=\"group\">\n\n    <mat-checkbox #matCheckbox\n                  [checked]=\"model.checked\"\n                  [color]=\"model.getAdditional('color', 'accent')\"\n                  [disableRipple]=\"model.getAdditional('disableRipple', RIPPLE_OPTIONS && RIPPLE_OPTIONS['disabled'] || false)\"\n                  [formControlName]=\"model.id\"\n                  [id]=\"id\"\n                  [indeterminate]=\"model.indeterminate\"\n                  [labelPosition]=\"model.labelPosition || 'after'\"\n                  [name]=\"model.name\"\n                  [ngClass]=\"[getClass('element', 'control'), getClass('grid', 'control')]\"\n                  (blur)=\"onBlur($event)\"\n                  (change)=\"onChange($event)\"\n                  (focus)=\"onFocus($event)\"\n                  (indeterminateChange)=\"onCustomEvent($event, 'indeterminateChange')\">\n\n        <span [ngClass]=\"getClass('element', 'label')\" [innerHTML]=\"model.label\"></span>\n\n    </mat-checkbox>\n\n</ng-container>\n"
    }),
    __param(2, Inject(MAT_RIPPLE_GLOBAL_OPTIONS)), __param(2, Optional()),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService, Object])
], DynamicMaterialCheckboxComponent);

let DynamicMaterialChipsComponent = class DynamicMaterialChipsComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService, AUTOCOMPLETE_OPTIONS, CHIPS_OPTIONS, LABEL_OPTIONS, RIPPLE_OPTIONS) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.AUTOCOMPLETE_OPTIONS = AUTOCOMPLETE_OPTIONS;
        this.CHIPS_OPTIONS = CHIPS_OPTIONS;
        this.LABEL_OPTIONS = LABEL_OPTIONS;
        this.RIPPLE_OPTIONS = RIPPLE_OPTIONS;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
    get chips() {
        return Array.isArray(this.model.value) ? this.model.value : [];
    }
    onChipInputTokenEnd($event) {
        const inputElement = $event.input, inputValue = $event.value.trim();
        if (inputValue.length > 0) {
            this.control.patchValue([...this.chips, inputValue]);
            this.onChange($event);
        }
        if (inputElement instanceof HTMLInputElement) {
            inputElement.value = "";
        }
    }
    onChipSelected($event) {
        const selectedChip = $event.option.value, chips = this.chips;
        if (!chips.includes(selectedChip)) {
            this.control.patchValue([...this.chips, selectedChip]);
        }
    }
    onChipRemoved(chip, index) {
        const chips = this.chips;
        if (chips[index] === chip) {
            chips.splice(index, 1);
            this.control.patchValue([...chips]);
        }
    }
};
DynamicMaterialChipsComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_AUTOCOMPLETE_DEFAULT_OPTIONS,] }] },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_CHIPS_DEFAULT_OPTIONS,] }] },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_LABEL_GLOBAL_OPTIONS,] }, { type: Optional }] },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_RIPPLE_GLOBAL_OPTIONS,] }, { type: Optional }] }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialChipsComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicMaterialChipsComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialChipsComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicInputModel)
], DynamicMaterialChipsComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialChipsComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialChipsComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialChipsComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialChipsComponent.prototype, "focus", void 0);
__decorate([
    ViewChild("matAutocomplete", { static: true }),
    __metadata("design:type", MatAutocomplete)
], DynamicMaterialChipsComponent.prototype, "matAutocomplete", void 0);
__decorate([
    ViewChild("matChipList", { static: true }),
    __metadata("design:type", MatChipList)
], DynamicMaterialChipsComponent.prototype, "matChipList", void 0);
__decorate([
    ViewChild(MatInput, { static: true }),
    __metadata("design:type", MatInput)
], DynamicMaterialChipsComponent.prototype, "matInput", void 0);
DynamicMaterialChipsComponent = __decorate([
    Component({
        selector: "dynamic-material-chips",
        template: "<mat-form-field [appearance]=\"model.getAdditional('appearance', 'legacy')\"\n                [color]=\"model.getAdditional('color', 'primary')\"\n                [floatLabel]=\"model.getAdditional('floatLabel', LABEL_OPTIONS && LABEL_OPTIONS['float'] || 'auto')\"\n                [formGroup]=\"group\"\n                [hideRequiredMarker]=\"model.getAdditional('hideRequiredMarker', false)\"\n                [ngClass]=\"getClass('grid', 'control')\">\n\n    <mat-chip-list #matChipList [formControlName]=\"model.id\" [id]=\"id\" [multiple]=\"true\">\n\n        <mat-chip *ngFor=\"let chip of chips; let index = index\"\n                  [selectable]=\"false\"\n                  (removed)=\"onChipRemoved(chip, index)\">\n\n            <span>{{ chip }}</span>\n\n            <mat-icon matChipRemove>cancel</mat-icon>\n\n        </mat-chip>\n\n        <input matInput\n               [matAutocomplete]=\"matAutocomplete\"\n               [matChipInputAddOnBlur]=\"model.getAdditional('matChipInputAddOnBlur', true)\"\n               [matChipInputFor]=\"matChipList\"\n               [matChipInputSeparatorKeyCodes]=\"model.getAdditional('matChipInputSeparatorKeyCodes', CHIPS_OPTIONS['separatorKeyCodes'])\"\n               [placeholder]=\"model.placeholder\"\n               (matChipInputTokenEnd)=\"onChipInputTokenEnd($event)\"\n               (blur)=\"onBlur($event)\"\n               (focus)=\"onFocus($event)\"/>\n\n        <mat-autocomplete #matAutocomplete=\"matAutocomplete\"\n                          [autoActiveFirstOption]=\"model.getAdditional('autoActiveFirstOption', AUTOCOMPLETE_OPTIONS['autoActiveFirstOption'])\"\n                          [disableRipple]=\"model.getAdditional('disableRipple', RIPPLE_OPTIONS && RIPPLE_OPTIONS['disabled'] || false)\"\n                          [displayWith]=\"model.getAdditional('displayWith', null)\"\n                          (optionSelected)=\"onChipSelected($event)\">\n\n            <mat-option *ngFor=\"let option of model.list$ | async\" [value]=\"option\">{{ option }}</mat-option>\n\n        </mat-autocomplete>\n\n    </mat-chip-list>\n\n</mat-form-field>\n"
    }),
    __param(2, Inject(MAT_AUTOCOMPLETE_DEFAULT_OPTIONS)),
    __param(3, Inject(MAT_CHIPS_DEFAULT_OPTIONS)),
    __param(4, Inject(MAT_LABEL_GLOBAL_OPTIONS)), __param(4, Optional()),
    __param(5, Inject(MAT_RIPPLE_GLOBAL_OPTIONS)), __param(5, Optional()),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService, Object, Object, Object, Object])
], DynamicMaterialChipsComponent);

let DynamicMaterialDatePickerComponent = class DynamicMaterialDatePickerComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService, LABEL_OPTIONS) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.LABEL_OPTIONS = LABEL_OPTIONS;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicMaterialDatePickerComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_LABEL_GLOBAL_OPTIONS,] }, { type: Optional }] }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialDatePickerComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicMaterialDatePickerComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialDatePickerComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicDatePickerModel)
], DynamicMaterialDatePickerComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialDatePickerComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialDatePickerComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialDatePickerComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialDatePickerComponent.prototype, "focus", void 0);
__decorate([
    ViewChild("matDatepicker", { static: true }),
    __metadata("design:type", MatDatepicker)
], DynamicMaterialDatePickerComponent.prototype, "matDatePicker", void 0);
__decorate([
    ViewChild(MatInput, { static: true }),
    __metadata("design:type", MatInput)
], DynamicMaterialDatePickerComponent.prototype, "matInput", void 0);
DynamicMaterialDatePickerComponent = __decorate([
    Component({
        selector: "dynamic-material-datepicker",
        template: "<mat-form-field [appearance]=\"model.getAdditional('appearance', 'legacy')\"\n                [color]=\"model.getAdditional('color', 'primary')\"\n                [floatLabel]=\"model.getAdditional('floatLabel', LABEL_OPTIONS && LABEL_OPTIONS['float'] || 'auto')\"\n                [formGroup]=\"group\"\n                [hideRequiredMarker]=\"model.getAdditional('hideRequiredMarker', false)\"\n                [ngClass]=\"getClass('grid', 'control')\">\n\n    <ng-container *ngIf=\"model.label\" ngProjectAs=\"mat-label\">\n\n        <mat-label [innerHTML]=\"model.label\"></mat-label>\n\n    </ng-container>\n\n    <span *ngIf=\"model.prefix\" matPrefix [innerHTML]=\"model.prefix\"></span>\n\n    <input matInput\n           [autofocus]=\"model.autoFocus\"\n           [formControlName]=\"model.id\"\n           [id]=\"id\"\n           [max]=\"model.max\"\n           [matDatepicker]=\"matDatepicker\"\n           [min]=\"model.min\"\n           [name]=\"model.name\"\n           [ngClass]=\"getClass('element', 'control')\"\n           [placeholder]=\"model.placeholder\"\n           [readonly]=\"model.readOnly\"\n           [required]=\"model.required\"\n           (blur)=\"onBlur($event)\"\n           (dateChange)=\"onChange($event)\"\n           (dateInput)=\"onCustomEvent($event, 'dateInput')\"\n           (focus)=\"onFocus($event)\"/>\n\n    <span *ngIf=\"model.suffix\" matSuffix [innerHTML]=\"model.suffix\"></span>\n\n    <mat-hint *ngIf=\"model.hint !== null\" align=\"start\" [innerHTML]=\"model.hint\"></mat-hint>\n\n\n    <mat-datepicker-toggle matSuffix [for]=\"matDatepicker\"></mat-datepicker-toggle>\n\n    <mat-datepicker #matDatepicker\n                    [opened]=\"model.getAdditional('opened', false)\"\n                    [startAt]=\"model.focusedDate\"\n                    [startView]=\"model.getAdditional('startView', 'month')\"\n                    [touchUi]=\"model.getAdditional('touchUi', false)\"\n                    (closed)=\"onCustomEvent($event, 'closed')\"\n                    (monthSelected)=\"onCustomEvent($event, 'monthSelected')\"\n                    (opened)=\"onCustomEvent($event, 'opened')\"\n                    (yearSelected)=\"onCustomEvent($event, 'yearSelected')\"></mat-datepicker>\n\n    <mat-error *ngFor=\"let message of errorMessages\">{{ message }}</mat-error>\n\n</mat-form-field>\n"
    }),
    __param(2, Inject(MAT_LABEL_GLOBAL_OPTIONS)), __param(2, Optional()),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService, Object])
], DynamicMaterialDatePickerComponent);

let DynamicMaterialInputComponent = class DynamicMaterialInputComponent extends DynamicMaterialFormInputControlComponent {
    constructor(layoutService, validationService, errorStateMatcher, AUTOCOMPLETE_OPTIONS, LABEL_OPTIONS, RIPPLE_OPTIONS) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.errorStateMatcher = errorStateMatcher;
        this.AUTOCOMPLETE_OPTIONS = AUTOCOMPLETE_OPTIONS;
        this.LABEL_OPTIONS = LABEL_OPTIONS;
        this.RIPPLE_OPTIONS = RIPPLE_OPTIONS;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicMaterialInputComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService },
    { type: ErrorStateMatcher, decorators: [{ type: Inject, args: [ErrorStateMatcher,] }] },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_AUTOCOMPLETE_DEFAULT_OPTIONS,] }] },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_LABEL_GLOBAL_OPTIONS,] }, { type: Optional }] },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_RIPPLE_GLOBAL_OPTIONS,] }, { type: Optional }] }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialInputComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicMaterialInputComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialInputComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicInputModel)
], DynamicMaterialInputComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialInputComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialInputComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialInputComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialInputComponent.prototype, "focus", void 0);
__decorate([
    ViewChild("matAutocomplete", { static: true }),
    __metadata("design:type", MatAutocomplete)
], DynamicMaterialInputComponent.prototype, "matAutocomplete", void 0);
__decorate([
    ViewChild(MatInput, { static: true }),
    __metadata("design:type", MatInput)
], DynamicMaterialInputComponent.prototype, "matInput", void 0);
DynamicMaterialInputComponent = __decorate([
    Component({
        selector: "dynamic-material-input",
        template: "<mat-form-field [appearance]=\"model.getAdditional('appearance', 'legacy')\"\n                [color]=\"model.getAdditional('color', 'primary')\"\n                [floatLabel]=\"model.getAdditional('floatLabel', LABEL_OPTIONS && LABEL_OPTIONS['float'] || 'auto')\"\n                [formGroup]=\"group\"\n                [hideRequiredMarker]=\"model.getAdditional('hideRequiredMarker', false)\"\n                [ngClass]=\"getClass('grid','control')\"\n                [textMask]=\"{mask: (model.mask || false), showMask: model.mask && !(model.placeholder)}\">\n\n    <ng-container *ngIf=\"model.label\" ngProjectAs=\"mat-label\">\n\n        <mat-label [innerHTML]=\"model.label\"></mat-label>\n\n    </ng-container>\n\n    <span *ngIf=\"model.prefix\" matPrefix [innerHTML]=\"model.prefix\"></span>\n\n    <input matInput\n           [attr.accept]=\"model.accept\"\n           [attr.max]=\"model.max\"\n           [attr.min]=\"model.min\"\n           [attr.multiple]=\"model.multiple\"\n           [attr.step]=\"model.step\"\n           [autocomplete]=\"model.autoComplete\"\n           [autofocus]=\"model.autoFocus\"\n           [errorStateMatcher]=\"model.getAdditional('errorStateMatcher', errorStateMatcher)\"\n           [formControlName]=\"model.id\"\n           [id]=\"id\"\n           [maxlength]=\"model.maxLength\"\n           [matAutocomplete]=\"matAutocomplete\"\n           [minlength]=\"model.minLength\"\n           [name]=\"model.name\"\n           [ngClass]=\"getClass('element', 'control')\"\n           [pattern]=\"model.pattern\"\n           [placeholder]=\"model.placeholder\"\n           [readonly]=\"model.readOnly\"\n           [required]=\"model.required\"\n           [spellcheck]=\"model.spellCheck\"\n           [tabindex]=\"model.tabIndex\"\n           [type]=\"model.inputType\"\n           (blur)=\"onBlur($event)\"\n           (change)=\"onChange($event)\"\n           (focus)=\"onFocus($event)\"/>\n\n    <span *ngIf=\"model.suffix\" matSuffix [innerHTML]=\"model.suffix\"></span>\n\n    <mat-hint *ngIf=\"model.hint !== null\" align=\"start\" [innerHTML]=\"model.hint\"></mat-hint>\n\n    <mat-hint *ngIf=\"showCharacterHint\" align=\"end\">{{ characterHint }}</mat-hint>\n\n    <mat-error *ngFor=\"let message of errorMessages\">{{ message }}</mat-error>\n\n</mat-form-field>\n\n<mat-autocomplete #matAutocomplete=\"matAutocomplete\"\n                  [autoActiveFirstOption]=\"model.getAdditional('autoActiveFirstOption', AUTOCOMPLETE_OPTIONS['autoActiveFirstOption'])\"\n                  [disableRipple]=\"model.getAdditional('disableRipple', RIPPLE_OPTIONS && RIPPLE_OPTIONS['disabled'] || false)\"\n                  [displayWith]=\"model.getAdditional('displayWith', null)\"\n                  (optionSelected)=\"onChange($event)\">\n\n    <mat-option *ngFor=\"let option of model.list$ | async\" [value]=\"option\">{{ option }}</mat-option>\n\n</mat-autocomplete>\n"
    }),
    __param(2, Inject(ErrorStateMatcher)),
    __param(3, Inject(MAT_AUTOCOMPLETE_DEFAULT_OPTIONS)),
    __param(4, Inject(MAT_LABEL_GLOBAL_OPTIONS)), __param(4, Optional()),
    __param(5, Inject(MAT_RIPPLE_GLOBAL_OPTIONS)), __param(5, Optional()),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService,
        ErrorStateMatcher, Object, Object, Object])
], DynamicMaterialInputComponent);

let DynamicMaterialTextAreaComponent = class DynamicMaterialTextAreaComponent extends DynamicMaterialFormInputControlComponent {
    constructor(layoutService, validationService, LABEL_OPTIONS) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.LABEL_OPTIONS = LABEL_OPTIONS;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicMaterialTextAreaComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_LABEL_GLOBAL_OPTIONS,] }, { type: Optional }] }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialTextAreaComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicMaterialTextAreaComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialTextAreaComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicTextAreaModel)
], DynamicMaterialTextAreaComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialTextAreaComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialTextAreaComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialTextAreaComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialTextAreaComponent.prototype, "focus", void 0);
__decorate([
    ViewChild(MatInput, { static: true }),
    __metadata("design:type", MatInput)
], DynamicMaterialTextAreaComponent.prototype, "matInput", void 0);
DynamicMaterialTextAreaComponent = __decorate([
    Component({
        selector: "dynamic-material-textarea",
        template: "<mat-form-field [appearance]=\"model.getAdditional('appearance', 'legacy')\"\n                [color]=\"model.getAdditional('color', 'primary')\"\n                [floatLabel]=\"model.getAdditional('floatLabel', LABEL_OPTIONS && LABEL_OPTIONS['float'] || 'auto')\"\n                [formGroup]=\"group\"\n                [hideRequiredMarker]=\"model.getAdditional('hideRequiredMarker', false)\"\n                [ngClass]=\"getClass('grid', 'control')\">\n\n    <ng-container *ngIf=\"model.label\" ngProjectAs=\"mat-label\">\n\n        <mat-label [innerHTML]=\"model.label\"></mat-label>\n\n    </ng-container>\n\n    <textarea matInput\n              [cdkTextareaAutosize]=\"model.getAdditional('cdkTextareaAutosize', true)\"\n              [cols]=\"model.cols\"\n              [formControlName]=\"model.id\"\n              [id]=\"id\"\n              [maxlength]=\"model.maxLength\"\n              [minlength]=\"model.minLength\"\n              [name]=\"model.name\"\n              [ngClass]=\"getClass('element', 'control')\"\n              [placeholder]=\"model.placeholder\"\n              [readonly]=\"model.readOnly\"\n              [required]=\"model.required\"\n              [rows]=\"model.rows\"\n              [spellcheck]=\"model.spellCheck\"\n              [tabindex]=\"model.tabIndex\"\n              [wrap]=\"model.wrap\"\n              (blur)=\"onBlur($event)\"\n              (change)=\"onChange($event)\"\n              (focus)=\"onFocus($event)\"></textarea>\n\n    <mat-hint *ngIf=\"model.hint !== null\" align=\"start\" [innerHTML]=\"model.hint\"></mat-hint>\n\n    <mat-hint *ngIf=\"showCharacterHint\" align=\"end\">{{ characterHint }}</mat-hint>\n\n    <mat-error *ngFor=\"let message of errorMessages\">{{ message }}</mat-error>\n\n</mat-form-field>\n"
    }),
    __param(2, Inject(MAT_LABEL_GLOBAL_OPTIONS)), __param(2, Optional()),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService, Object])
], DynamicMaterialTextAreaComponent);

let DynamicMaterialSlideToggleComponent = class DynamicMaterialSlideToggleComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService, RIPPLE_OPTIONS) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.RIPPLE_OPTIONS = RIPPLE_OPTIONS;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicMaterialSlideToggleComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_RIPPLE_GLOBAL_OPTIONS,] }, { type: Optional }] }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialSlideToggleComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicMaterialSlideToggleComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialSlideToggleComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicSwitchModel)
], DynamicMaterialSlideToggleComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialSlideToggleComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialSlideToggleComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialSlideToggleComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialSlideToggleComponent.prototype, "focus", void 0);
__decorate([
    ViewChild("matSlideToggle", { static: true }),
    __metadata("design:type", MatSlideToggle)
], DynamicMaterialSlideToggleComponent.prototype, "matSlideToggle", void 0);
DynamicMaterialSlideToggleComponent = __decorate([
    Component({
        selector: "dynamic-material-slide-toggle",
        template: "<ng-container [formGroup]=\"group\">\n\n    <mat-slide-toggle #matSlideToggle\n                      [checked]=\"model.checked\"\n                      [color]=\"model.getAdditional('color', 'accent')\"\n                      [disableRipple]=\"model.getAdditional('disableRipple', RIPPLE_OPTIONS && RIPPLE_OPTIONS['disabled'] || false)\"\n                      [formControlName]=\"model.id\"\n                      [id]=\"id\"\n                      [labelPosition]=\"model.labelPosition || 'after'\"\n                      [name]=\"model.name\"\n                      [ngClass]=\"[getClass('element','control'), getClass('grid','control')]\"\n                      (change)=\"onChange($event)\"\n                      (dragChange)=\"onCustomEvent($event, 'dragChange')\"\n                      (toggleChange)=\"onCustomEvent($event, 'toggleChange')\">\n\n        <span *ngIf=\"!model.checked\" [innerHTML]=\"model.offLabel\"></span>\n\n        <span *ngIf=\"model.checked\" [innerHTML]=\"model.onLabel\"></span>\n\n    </mat-slide-toggle>\n\n</ng-container>\n"
    }),
    __param(2, Inject(MAT_RIPPLE_GLOBAL_OPTIONS)), __param(2, Optional()),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService, Object])
], DynamicMaterialSlideToggleComponent);

let DynamicMaterialSliderComponent = class DynamicMaterialSliderComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicMaterialSliderComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialSliderComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicMaterialSliderComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialSliderComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicSliderModel)
], DynamicMaterialSliderComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialSliderComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialSliderComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialSliderComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialSliderComponent.prototype, "focus", void 0);
__decorate([
    ViewChild("matSlider", { static: true }),
    __metadata("design:type", MatSlider)
], DynamicMaterialSliderComponent.prototype, "matSlider", void 0);
DynamicMaterialSliderComponent = __decorate([
    Component({
        selector: "dynamic-material-slider",
        template: "<ng-container [formGroup]=\"group\">\n\n    <mat-slider #matSlider\n                [color]=\"model.getAdditional('color', 'accent')\"\n                [formControlName]=\"model.id\"\n                [id]=\"id\"\n                [invert]=\"model.getAdditional('invert', false)\"\n                [min]=\"model.min\"\n                [max]=\"model.max\"\n                [ngClass]=\"[getClass('element', 'control'), getClass('grid', 'control')]\"\n                [step]=\"model.step\"\n                [tabIndex]=\"model.tabIndex\"\n                [thumbLabel]=\"model.getAdditional('thumbLabel', true)\"\n                [tickInterval]=\"model.getAdditional('tickInterval', 1)\"\n                [vertical]=\"model.vertical\"\n                (change)=\"onChange($event)\"\n                (input)=\"onCustomEvent($event, 'input')\"></mat-slider>\n\n</ng-container>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicMaterialSliderComponent);

let DynamicMaterialRadioGroupComponent = class DynamicMaterialRadioGroupComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicMaterialRadioGroupComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialRadioGroupComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicMaterialRadioGroupComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialRadioGroupComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicRadioGroupModel)
], DynamicMaterialRadioGroupComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialRadioGroupComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialRadioGroupComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialRadioGroupComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialRadioGroupComponent.prototype, "focus", void 0);
__decorate([
    ViewChild("matRadioGroup", { static: true }),
    __metadata("design:type", MatRadioGroup)
], DynamicMaterialRadioGroupComponent.prototype, "matRadioGroup", void 0);
DynamicMaterialRadioGroupComponent = __decorate([
    Component({
        selector: "dynamic-material-radio-group",
        template: "<ng-container [formGroup]=\"group\">\n\n    <mat-radio-group #matRadioGroup\n                     [formControlName]=\"model.id\"\n                     [id]=\"id\"\n                     [labelPosition]=\"model.getAdditional('labelPosition', 'after')\"\n                     [name]=\"model.name\"\n                     [ngClass]=\"[getClass('element', 'control'), getClass('grid', 'control')]\"\n                     [required]=\"model.required\"\n                     (blur)=\"onBlur($event)\"\n                     (change)=\"onChange($event)\"\n                     (focus)=\"onFocus($event)\">\n\n        <mat-radio-button *ngFor=\"let option of model.options$ | async\"\n                          [name]=\"model.name\"\n                          [ngClass]=\"getClass('element', 'option')\"\n                          [value]=\"option.value\"><span [innerHTML]=\"option.label\"></span></mat-radio-button>\n\n    </mat-radio-group>\n\n</ng-container>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicMaterialRadioGroupComponent);

let DynamicMaterialSelectComponent = class DynamicMaterialSelectComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService, errorStateMatcher, LABEL_OPTIONS, RIPPLE_OPTIONS) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.errorStateMatcher = errorStateMatcher;
        this.LABEL_OPTIONS = LABEL_OPTIONS;
        this.RIPPLE_OPTIONS = RIPPLE_OPTIONS;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicMaterialSelectComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService },
    { type: ErrorStateMatcher, decorators: [{ type: Inject, args: [ErrorStateMatcher,] }] },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_LABEL_GLOBAL_OPTIONS,] }, { type: Optional }] },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_RIPPLE_GLOBAL_OPTIONS,] }, { type: Optional }] }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialSelectComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicMaterialSelectComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialSelectComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicSelectModel)
], DynamicMaterialSelectComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialSelectComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialSelectComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialSelectComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialSelectComponent.prototype, "focus", void 0);
__decorate([
    ViewChild("matSelect", { static: true }),
    __metadata("design:type", MatSelect)
], DynamicMaterialSelectComponent.prototype, "matSelect", void 0);
DynamicMaterialSelectComponent = __decorate([
    Component({
        selector: "dynamic-material-select",
        template: "<mat-form-field [appearance]=\"model.getAdditional('appearance', 'legacy')\"\n                [color]=\"model.getAdditional('color', 'primary')\"\n                [ngClass]=\"getClass('grid', 'control')\"\n                [floatLabel]=\"model.getAdditional('floatLabel', LABEL_OPTIONS && LABEL_OPTIONS['float'] || 'auto')\"\n                [formGroup]=\"group\">\n\n    <ng-container *ngIf=\"model.label\" ngProjectAs=\"mat-label\">\n\n        <mat-label [innerHTML]=\"model.label\"></mat-label>\n\n    </ng-container>\n\n    <span *ngIf=\"model.prefix\" matPrefix [innerHTML]=\"model.prefix\"></span>\n\n    <mat-select #matSelect\n                [compareWith]=\"model.compareWithFn\"\n                [disableOptionCentering]=\"model.getAdditional('disableOptionCentering', false)\"\n                [disableRipple]=\"model.getAdditional('disableRipple', RIPPLE_OPTIONS && RIPPLE_OPTIONS['disabled'] || false)\"\n                [errorStateMatcher]=\"model.getAdditional('errorStateMatcher', errorStateMatcher)\"\n                [formControlName]=\"model.id\"\n                [id]=\"id\"\n                [multiple]=\"model.multiple\"\n                [ngClass]=\"getClass('element', 'control')\"\n                [placeholder]=\"model.placeholder\"\n                [required]=\"model.required\"\n                (openedChange)=\"onCustomEvent($event, 'openedChange')\"\n                (selectionChange)=\"onChange($event)\">\n\n        <mat-option *ngFor=\"let option of model.options$ | async\"\n                    [disabled]=\"option.disabled\"\n                    [ngClass]=\"getClass('element', 'option')\"\n                    [value]=\"option.value\"><span [innerHTML]=\"option.label\"></span></mat-option>\n    </mat-select>\n\n    <span *ngIf=\"model.suffix\" matSuffix [innerHTML]=\"model.suffix\"></span>\n\n    <mat-hint *ngIf=\"model.hint !== null\" align=\"start\" [innerHTML]=\"model.hint\"></mat-hint>\n\n    <mat-error *ngFor=\"let message of errorMessages\">{{ message }}</mat-error>\n\n</mat-form-field>\n"
    }),
    __param(2, Inject(ErrorStateMatcher)),
    __param(3, Inject(MAT_LABEL_GLOBAL_OPTIONS)), __param(3, Optional()),
    __param(4, Inject(MAT_RIPPLE_GLOBAL_OPTIONS)), __param(4, Optional()),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService,
        ErrorStateMatcher, Object, Object])
], DynamicMaterialSelectComponent);

let DynamicMaterialFormGroupComponent = class DynamicMaterialFormGroupComponent extends DynamicFormGroupComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicMaterialFormGroupComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialFormGroupComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicMaterialFormGroupComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialFormGroupComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicFormGroupModel)
], DynamicMaterialFormGroupComponent.prototype, "model", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialFormGroupComponent.prototype, "templates", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialFormGroupComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialFormGroupComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialFormGroupComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialFormGroupComponent.prototype, "focus", void 0);
__decorate([
    ViewChildren(forwardRef(() => DynamicMaterialFormControlContainerComponent)),
    __metadata("design:type", QueryList)
], DynamicMaterialFormGroupComponent.prototype, "components", void 0);
DynamicMaterialFormGroupComponent = __decorate([
    Component({
        selector: "dynamic-material-form-group",
        template: "<ng-container [formGroup]=\"group\">\n\n    <div role=\"group\"\n         [formGroupName]=\"model.id\"\n         [id]=\"id\"\n         [ngClass]=\"[getClass('element', 'control'), getClass('grid', 'control')]\">\n\n        <dynamic-material-form-control *ngFor=\"let _model of model.group\"\n                                       [group]=\"control\"\n                                       [hidden]=\"_model.hidden\"\n                                       [layout]=\"formLayout\"\n                                       [model]=\"_model\"\n                                       [templates]=\"templates\"\n                                       [hostClass]=\"[getClass('element','children'), getClass('grid','children')]\"\n                                       (blur)=\"onBlur($event)\"\n                                       (change)=\"onChange($event)\"\n                                       (focus)=\"onFocus($event)\"\n                                       (matEvent)=\"onCustomEvent($event, null, true)\"></dynamic-material-form-control>\n    </div>\n\n</ng-container>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicMaterialFormGroupComponent);

let DynamicMaterialFormControlContainerComponent = class DynamicMaterialFormControlContainerComponent extends DynamicFormControlContainerComponent {
    constructor(changeDetectorRef, componentFactoryResolver, layoutService, validationService, componentService, relationService) {
        super(changeDetectorRef, componentFactoryResolver, layoutService, validationService, componentService, relationService);
        this.changeDetectorRef = changeDetectorRef;
        this.componentFactoryResolver = componentFactoryResolver;
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.componentService = componentService;
        this.relationService = relationService;
        this.context = null;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
        this.customEvent = new EventEmitter();
    }
    get componentType() {
        return this.componentService.getCustomComponentType(this.model) || materialUIFormControlMapFn(this.model);
    }
    get hasMatFormField() {
        const matFormFieldTypes = [DYNAMIC_FORM_CONTROL_TYPE_DATEPICKER, DYNAMIC_FORM_CONTROL_TYPE_INPUT,
            DYNAMIC_FORM_CONTROL_TYPE_SELECT, DYNAMIC_FORM_CONTROL_TYPE_TEXTAREA];
        return matFormFieldTypes.some(type => this.model.type === type) || (this.model instanceof DynamicFormValueControlModel &&
            this.model.getAdditional("isFormFieldControl"));
    }
};
DynamicMaterialFormControlContainerComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ComponentFactoryResolver },
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService },
    { type: DynamicFormComponentService },
    { type: DynamicFormRelationService }
];
__decorate([
    ContentChildren(DynamicTemplateDirective),
    __metadata("design:type", QueryList)
], DynamicMaterialFormControlContainerComponent.prototype, "contentTemplateList", void 0);
__decorate([
    HostBinding("class"),
    __metadata("design:type", Object)
], DynamicMaterialFormControlContainerComponent.prototype, "klass", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicFormArrayGroupModel)
], DynamicMaterialFormControlContainerComponent.prototype, "context", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicMaterialFormControlContainerComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], DynamicMaterialFormControlContainerComponent.prototype, "hostClass", void 0);
__decorate([
    Input("templates"),
    __metadata("design:type", QueryList)
], DynamicMaterialFormControlContainerComponent.prototype, "inputTemplateList", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialFormControlContainerComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicFormControlModel)
], DynamicMaterialFormControlContainerComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialFormControlContainerComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialFormControlContainerComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialFormControlContainerComponent.prototype, "focus", void 0);
__decorate([
    Output("matEvent"),
    __metadata("design:type", EventEmitter)
], DynamicMaterialFormControlContainerComponent.prototype, "customEvent", void 0);
__decorate([
    ViewChild("componentViewContainer", { read: ViewContainerRef, static: true }),
    __metadata("design:type", ViewContainerRef)
], DynamicMaterialFormControlContainerComponent.prototype, "componentViewContainerRef", void 0);
DynamicMaterialFormControlContainerComponent = __decorate([
    Component({
        selector: "dynamic-material-form-control",
        template: "<div [formGroup]=\"group\"\n     [ngClass]=\"['ng-dynamic-forms-'+model.type.toLowerCase(), getClass('element', 'container'), getClass('grid', 'container')]\">\n\n    <label *ngIf=\"!hasMatFormField && !isCheckbox && hasLabel\"\n           [for]=\"id\"\n           [innerHTML]=\"model.label\"\n           [ngClass]=\"[getClass('element', 'label'), getClass('grid', 'label')]\"></label>\n\n    <ng-container *ngTemplateOutlet=\"startTemplate?.templateRef; context: model\"></ng-container>\n\n    <ng-container #componentViewContainer></ng-container>\n\n    <ng-container *ngIf=\"!hasMatFormField\">\n\n        <mat-error *ngFor=\"let message of errorMessages\">{{ message }}</mat-error>\n\n    </ng-container>\n\n    <ng-container *ngTemplateOutlet=\"endTemplate?.templateRef; context: model\"></ng-container>\n\n    <ng-content></ng-content>\n\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [ChangeDetectorRef,
        ComponentFactoryResolver,
        DynamicFormLayoutService,
        DynamicFormValidationService,
        DynamicFormComponentService,
        DynamicFormRelationService])
], DynamicMaterialFormControlContainerComponent);
function materialUIFormControlMapFn(model) {
    switch (model.type) {
        case DYNAMIC_FORM_CONTROL_TYPE_ARRAY:
            return DynamicMaterialFormArrayComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX:
            return DynamicMaterialCheckboxComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX_GROUP:
            return DynamicMaterialFormGroupComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_DATEPICKER:
            return DynamicMaterialDatePickerComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_GROUP:
            return DynamicMaterialFormGroupComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_INPUT:
            const inputModel = model;
            return inputModel.multiple ? DynamicMaterialChipsComponent : DynamicMaterialInputComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_RADIO_GROUP:
            return DynamicMaterialRadioGroupComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_SELECT:
            return DynamicMaterialSelectComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_SLIDER:
            return DynamicMaterialSliderComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_SWITCH:
            return DynamicMaterialSlideToggleComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_TEXTAREA:
            return DynamicMaterialTextAreaComponent;
        default:
            return null;
    }
}

let DynamicMaterialFormArrayComponent = class DynamicMaterialFormArrayComponent extends DynamicFormArrayComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicMaterialFormArrayComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialFormArrayComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicMaterialFormArrayComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialFormArrayComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicFormArrayModel)
], DynamicMaterialFormArrayComponent.prototype, "model", void 0);
__decorate([
    Input(),
    __metadata("design:type", QueryList)
], DynamicMaterialFormArrayComponent.prototype, "templates", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialFormArrayComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialFormArrayComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialFormArrayComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialFormArrayComponent.prototype, "focus", void 0);
__decorate([
    ViewChildren(forwardRef(() => DynamicMaterialFormControlContainerComponent)),
    __metadata("design:type", QueryList)
], DynamicMaterialFormArrayComponent.prototype, "components", void 0);
DynamicMaterialFormArrayComponent = __decorate([
    Component({
        selector: "dynamic-material-form-array",
        template: "<ng-container [formGroup]=\"group\">\n\n    <div [formArrayName]=\"model.id\" [id]=\"id\" [ngClass]=\"getClass('element', 'control')\">\n\n        <div *ngFor=\"let groupModel of model.groups; let idx = index\" role=\"group\"\n             [formGroupName]=\"idx\" [ngClass]=\"[getClass('element', 'group'), getClass('grid', 'group')]\">\n\n            <ng-container *ngTemplateOutlet=\"startTemplate?.templateRef; context: groupModel\"></ng-container>\n\n            <dynamic-material-form-control *ngFor=\"let _model of groupModel.group\"\n                                           [context]=\"groupModel\"\n                                           [group]=\"array.at(idx)\"\n                                           [hidden]=\"_model.hidden\"\n                                           [layout]=\"formLayout\"\n                                           [model]=\"_model\"\n                                           [templates]=\"templates\"\n                                           [hostClass]=\"[getClass('element','children'), getClass('grid','children')]\"\n                                           (blur)=\"onBlur($event)\"\n                                           (change)=\"onChange($event)\"\n                                           (focus)=\"onFocus($event)\"\n                                           (matEvent)=\"onCustomEvent($event, null, true)\"></dynamic-material-form-control>\n\n            <ng-container *ngTemplateOutlet=\"endTemplate?.templateRef; context: groupModel\"></ng-container>\n\n        </div>\n\n    </div>\n\n</ng-container>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicMaterialFormArrayComponent);

let DynamicMaterialFormComponent = class DynamicMaterialFormComponent extends DynamicFormComponent {
    constructor(changeDetectorRef, componentService) {
        super(changeDetectorRef, componentService);
        this.changeDetectorRef = changeDetectorRef;
        this.componentService = componentService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
        this.matEvent = new EventEmitter();
    }
};
DynamicMaterialFormComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: DynamicFormComponentService }
];
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicMaterialFormComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], DynamicMaterialFormComponent.prototype, "model", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicMaterialFormComponent.prototype, "layout", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialFormComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialFormComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialFormComponent.prototype, "focus", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicMaterialFormComponent.prototype, "matEvent", void 0);
__decorate([
    ContentChildren(DynamicTemplateDirective),
    __metadata("design:type", QueryList)
], DynamicMaterialFormComponent.prototype, "templates", void 0);
__decorate([
    ViewChildren(DynamicMaterialFormControlContainerComponent),
    __metadata("design:type", QueryList)
], DynamicMaterialFormComponent.prototype, "components", void 0);
DynamicMaterialFormComponent = __decorate([
    Component({
        selector: "dynamic-material-form",
        template: "<dynamic-material-form-control *ngFor=\"let controlModel of model; trackBy: trackByFn\"\n                               [group]=\"group\"\n                               [hidden]=\"controlModel.hidden\"\n                               [layout]=\"layout\"\n                               [model]=\"controlModel\"\n                               [templates]=\"templates\"\n                               (blur)=\"onBlur($event)\"\n                               (change)=\"onChange($event)\"\n                               (focus)=\"onFocus($event)\"\n                               (matEvent)=\"onCustomEvent($event, matEvent)\"></dynamic-material-form-control>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [ChangeDetectorRef,
        DynamicFormComponentService])
], DynamicMaterialFormComponent);

let DynamicFormsMaterialUIModule = class DynamicFormsMaterialUIModule {
};
DynamicFormsMaterialUIModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            ReactiveFormsModule,
            MatAutocompleteModule,
            MatCheckboxModule,
            MatChipsModule,
            MatDatepickerModule,
            MatIconModule,
            MatInputModule,
            MatRadioModule,
            MatSelectModule,
            MatSliderModule,
            MatSlideToggleModule,
            TextMaskModule,
            DynamicFormsCoreModule
        ],
        declarations: [
            DynamicMaterialCheckboxComponent,
            DynamicMaterialChipsComponent,
            DynamicMaterialDatePickerComponent,
            DynamicMaterialFormArrayComponent,
            DynamicMaterialFormComponent,
            DynamicMaterialFormControlContainerComponent,
            DynamicMaterialFormGroupComponent,
            DynamicMaterialInputComponent,
            DynamicMaterialRadioGroupComponent,
            DynamicMaterialSelectComponent,
            DynamicMaterialSlideToggleComponent,
            DynamicMaterialSliderComponent,
            DynamicMaterialTextAreaComponent
        ],
        entryComponents: [
            DynamicMaterialCheckboxComponent,
            DynamicMaterialChipsComponent,
            DynamicMaterialDatePickerComponent,
            DynamicMaterialFormArrayComponent,
            DynamicMaterialFormGroupComponent,
            DynamicMaterialInputComponent,
            DynamicMaterialRadioGroupComponent,
            DynamicMaterialSelectComponent,
            DynamicMaterialSlideToggleComponent,
            DynamicMaterialSliderComponent,
            DynamicMaterialTextAreaComponent
        ],
        exports: [
            DynamicFormsCoreModule,
            DynamicMaterialCheckboxComponent,
            DynamicMaterialChipsComponent,
            DynamicMaterialDatePickerComponent,
            DynamicMaterialFormArrayComponent,
            DynamicMaterialFormComponent,
            DynamicMaterialFormControlContainerComponent,
            DynamicMaterialFormGroupComponent,
            DynamicMaterialInputComponent,
            DynamicMaterialRadioGroupComponent,
            DynamicMaterialSelectComponent,
            DynamicMaterialSlideToggleComponent,
            DynamicMaterialSliderComponent,
            DynamicMaterialTextAreaComponent
        ]
    })
], DynamicFormsMaterialUIModule);

/**
 * Generated bundle index. Do not edit.
 */

export { DynamicFormsMaterialUIModule, DynamicMaterialCheckboxComponent, DynamicMaterialChipsComponent, DynamicMaterialDatePickerComponent, DynamicMaterialFormArrayComponent, DynamicMaterialFormComponent, DynamicMaterialFormControlContainerComponent, DynamicMaterialFormGroupComponent, DynamicMaterialFormInputControlComponent, DynamicMaterialInputComponent, DynamicMaterialRadioGroupComponent, DynamicMaterialSelectComponent, DynamicMaterialSlideToggleComponent, DynamicMaterialSliderComponent, DynamicMaterialTextAreaComponent, materialUIFormControlMapFn };
//# sourceMappingURL=ui-material.js.map
